rnalysis.feature\_name\_to\_wbgene.GeneNameTranslator.generate\_target\_dict
============================================================================

.. currentmodule:: rnalysis.feature_name_to_wbgene

.. automethod:: GeneNameTranslator.generate_target_dict